@@ -5,27 +5,27 @@ import shutil
 import backstage
 import subprocess
 
-class Project():
-    """A backstage project is a specific local install of backstage."""
-    def __init__(self,project_root):
-        """Initialize a Backstage Project instance. Required arguments are the name of the project and the fullpath of the project (name included)
+class Venue():
+    """A backstage Venue is a specific local install of backstage."""
+    def __init__(self,venue_root):
+        """Initialize a Backstage Venue instance. Required arguments are the name of the venue and the fullpath of the venue (name included)
         """
-        self.PROJECT_ROOT = os.path.abspath(project_root)
-        self.PROJECT_PATH,self.PROJECT_DIRNAME = os.path.split(self.PROJECT_ROOT)
-        self.PROJECT_NAME = self.PROJECT_DIRNAME
+        self.VENUE_ROOT = os.path.abspath(venue_root)
+        self.VENUE_PATH,self.VENUE_DIRNAME = os.path.split(self.VENUE_ROOT)
+        self.VENUE_NAME = self.VENUE_DIRNAME
 
-        #ensure that the project path is on sys.path
-        self.PROJECT_PATH in sys.path or sys.path.insert(0,self.PROJECT_PATH)
+        #ensure that the venue path is on sys.path
+        self.VENUE_PATH in sys.path or sys.path.insert(0,self.VENUE_PATH)
         self.get_settings()
 
     def __unicode__(self):
-        s = 'Django Backstage project named %s at %s' % (self.PROJECT_NAME, self.PROJECT_PATH)
+        s = 'Django Backstage Venue named %s at %s' % (self.VENUE_NAME, self.VENUE_PATH)
         return s
 
     def get_settings(self):
-        """ import the project's settings.py"""
+        """ import the venue's settings.py"""
         try:
-            exec_string = 'from %s import settings' % self.PROJECT_NAME
+            exec_string = 'from %s import settings' % self.VENUE_NAME
             print exec_string
             exec(exec_string)
             self.settings = settings
@@ -34,7 +34,7 @@ class Project():
             raise
 
     def connect(self):
-        """ connect to the project database """
+        """ connect to the venue database """
         import psycopg2
         try:
             db = self.settings.DATABASES['default']
@@ -71,7 +71,7 @@ class Project():
             self.sites
         except:
             self.getallsites()
-        skel = os.path.join(self.settings.PROJECT_ROOT, 'skel/site')
+        skel = os.path.join(self.settings.VENUE_ROOT, 'skel/site')
         for s in self.sites:
             site = backstage.Site(s)
             print 'Site:  %s' % (site.sitename)
@@ -82,7 +82,7 @@ class Project():
         if f is None:
             print 'File Name Required.'
             return False
-        infile = os.path.join(self.settings.PROJECT_ROOT, 'skel/site', f)
+        infile = os.path.join(self.settings.VENUE_ROOT, 'skel/site', f)
         infile += '.src'
         if not os.path.exists(infile):
             print 'source file %s not found' % (infile)
@@ -97,7 +97,7 @@ class Project():
 
     def dumpsettings(self):
         try:
-            outfile = os.path.join(self.PROJECT_ROOT,'settings_dump.py')
+            outfile = os.path.join(self.VENUE_ROOT,'settings_dump.py')
             of = open(outfile, 'w')
             my_settings = dir(self.settings)
             for my_setting in my_settings:
@@ -110,9 +110,9 @@ class Project():
         return True
 
     def build_virtualenv(self):
-        """build the virtual environment for this backstage project"""
+        """build the virtual environment for this backstage venue"""
         cwd = os.getcwd()
-        venvdir = os.path.join(self.PROJECT_ROOT,'venv')
+        venvdir = os.path.join(self.VENUE_ROOT,'venv')
         cmd = '%s/build_virtualenv' % (venvdir)
         st = os.stat(cmd)
         os.chmod(cmd, st.st_mode | stat.S_IEXEC)
@@ -121,34 +121,34 @@ class Project():
         os.chdir(cwd)
         return
 
-def copy_project_skel(project_path):
-    """Populate a (usually) new backstage project with the contents of backstage/skel"""
+def copy_venue_skel(venue_path):
+    """Populate a (usually) new backstage venue with the contents of backstage/skel"""
     skeldir = os.path.join(os.path.dirname(backstage.__file__),'skel')
     if not os.path.exists(skeldir):
-        s = 'Source skeleton files for backstage project not found.  This is a system error'
+        s = 'Source skeleton files for backstage venue not found.  This is a system error'
         print s
         raise
     try:
-        #Copy the contents of the 'skel' folder into the project root
-        os.system("cp -rpv %s/* %s" % (skeldir, project_path))
+        #Copy the contents of the 'skel' folder into the venue root
+        os.system("cp -rpv %s/* %s" % (skeldir, venue_path))
 
     except:
-        s = "ERROR copying the project skel into %s" % project_path
+        s = "ERROR copying the venue skel into %s" % venue_path
         print s
         raise
     return True
 
-def new_project(project_name, project_path, source_ini_file = None):
-        """create a new backstage project with the given name and located at the specified path"""
-        project_path = os.path.abspath(os.path.join(project_path, project_name))
+def new_venue(venue_name, venue_path, source_ini_file = None):
+        """create a new backstage venue with the given name and located at the specified path"""
+        venue_path = os.path.abspath(os.path.join(venue_path, venue_name))
         try:
-            os.makedirs(project_path)
+            os.makedirs(venue_path)
         except:
-            print 'Error creating project.'
+            print 'Error creating venue.'
             raise
 
         try:
-            with open(os.path.join(project_path, '__init__.py'), 'w'):
+            with open(os.path.join(venue_path, '__init__.py'), 'w'):
                 pass
         except:
             err = 'ERROR with init file'
@@ -157,7 +157,7 @@ def new_project(project_name, project_path, source_ini_file = None):
         try:
             if source_ini_file is not None:
                 pass  #try to copy the file
-            fh=open(os.path.join(project_path, 'backstage.ini'), 'w')
+            fh=open(os.path.join(venue_path, 'backstage.ini'), 'w')
             fh.write('[backstage]\n')
             fh.close()
         except:
@@ -165,73 +165,73 @@ def new_project(project_name, project_path, source_ini_file = None):
             raise
 
         try:
-            copy_project_skel(project_path)
+            copy_venue_skel(venue_path)
         except:
-            s = 'Error in copy_project_skel'
+            s = 'Error in copy_venue_skel'
             print s
             raise
 
 
 
         try:
-            p = use_project(project_path)
+            p = use_venue(venue_path)
         except:
             raise
 
         p.build_virtualenv()
-        s = 'Successfully created Backstage project %s at %s' % (p.PROJECT_NAME, p.PROJECT_ROOT)
+        s = 'Successfully created Backstage venue %s at %s' % (p.VENUE_NAME, p.VENUE_ROOT)
         print s
         return p
 
-def test_project_exists(project_root):
-    """Test for the existence of a Backstage Project instance.  Return True or False"""
-    if not os.path.exists(project_root):
-        s = 'Project folder at %s does not exist. Terminating' % project_root
+def test_venue_exists(venue_root):
+    """Test for the existence of a Backstage venue instance.  Return True or False"""
+    if not os.path.exists(venue_root):
+        s = 'venue folder at %s does not exist. Terminating' % venue_root
         print s
         return False
-    #A file named backstage.ini should exist.  Proves this is a backstage project.  Right now it is empty
-    ini_file = os.path.join(project_root, 'backstage.ini')
+    #A file named backstage.ini should exist.  Proves this is a backstage venue.  Right now it is empty
+    ini_file = os.path.join(venue_root, 'backstage.ini')
     if not os.path.exists(ini_file):
         s = 'Backstage INI file not found'
         print s
         return False
     return True
 
-def use_project(project_root):
-    """Use an existing Backstage project.  Returns the Project instance."""
-    exists = test_project_exists(project_root)
+def use_venue(venue_root):
+    """Use an existing Backstage venue.  Returns the venue instance."""
+    exists = test_venue_exists(venue_root)
     if not exists:
-        s = 'Project does not exist'
+        s = 'venue does not exist'
         print s
         raise
 
     try:
-        backstage_project = Project(project_root)
+        backstage_venue = venue(venue_root)
     except:
         raise
-    paths = [backstage_project.PROJECT_ROOT, backstage_project.PROJECT_PATH, ]
+    paths = [backstage_venue.VENUE_ROOT, backstage_venue.VENUE_PATH, ]
     for pth in paths:
         if not pth in sys.path:
             sys.path.append(pth)
     try:
-        backstage_project.get_settings()
+        backstage_venue.get_settings()
     except:
         s = 'Could not import settings'
         print s
         raise
     # paramfiles are those with parameterized variables needing to be replaced using the params dict.
-    backstage_project.paramfiles = ['site_settings.py', 'theme_settings.py', 'wsgi.py', 'conf/gunicorn_launcher',
+    backstage_venue.paramfiles = ['site_settings.py', 'theme_settings.py', 'wsgi.py', 'conf/gunicorn_launcher',
                    'conf/nginx.conf', 'templates/index.html',
                    'conf/supervisor.conf', ]
     # this would be better in a db table
-    backstage_project.themes = ['default', 'default24', 'fluid', 'container', 'hero', ]
+    backstage_venue.themes = ['default', 'default24', 'fluid', 'container', 'hero', ]
     try:
-        backstage_project.connect()
+        backstage_venue.connect()
     except:
         s = 'Could not connect to database'
         raise
-    s = 'Using Backstage Project %s at %s' % (backstage_project.PROJECT_NAME, backstage_project.PROJECT_ROOT)
+    s = 'Using Backstage venue %s at %s' % (backstage_venue.VENUE_NAME, backstage_venue.VENUE_ROOT)
     print s
-    return backstage_project
+    return backstage_venue
 
 
